==> iFlow_2.2.0.tar.gz: iFlow/R/openFilter.R <==
write.list <- function()
{
  ## update filter list on the data panel
   n <- length(names(.guiEnv$Gate.list))
   iget("fcon")$appendRows(data.frame(cols = names(.guiEnv$Gate.list)[n]))
}  


callgate <- function(gating, id)
{
  .guiEnv$Gate.list[[id]] <- gating

   write.list()
  
} 
                                                     


rect <- function (mode) 
{
    
    fdetail <- ask.dialog("RectangleGate",channel.selections = c("X Channel", "Y Channel") )
     
     parms<-list(fdetail[[6]], fdetail[[5]])
     names(parms) <- c(fdetail$selected.channels[[2]], fdetail$selected.channels[[1]])
        
     tryCatch( gating <- rectangleGate(parms), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
    
     name <- fdetail$id[1]
     
     if(name %in% names(.guiEnv$Gate.list)) 
     { 
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }
     }  
     callgate(gating, name)
     
 }  

 
 
quad <- function(mode)
{
   fdetail<- ask.dialog("QuadrantGate",channel.selections = c("X Channel", "Y Channel") )
   
   parms <- list(fdetail[[5]], fdetail[[6]])
   names(parms) <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    
   tryCatch( gating <- quadGate(parms), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })

     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
     
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))
     {
       while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
        }
     }  
     callgate(gating, name)
    
 }


 
 
 lymph <- function(mode)
{
   
  fdetail<- ask.dialog("LymphFilter",channel.selections = c("X Channel", "Y Channel", "PreSelection") )
  if(fdetail$ok)
  {
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    pre <- fdetail$selected.channels[[3]]
    
    tryCatch( gating <- lymphFilter(parms, preselection = pre), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
    
     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
      
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     { 
        while(name %in% names(.guiEnv$Gate.list))
       {   
            name <- paste(name, collapse = "*")
       }
     }
     callgate(gating, name)
   
 }  
  
}



 
k_mean <- function(mode)
{
 
  fdetail<- ask.dialog("Kmeans",channel.selections = c("Channel") )
  if(fdetail$ok)
  {
   
     parms <- list(c("Low", "Medium", "High"))
     names(parms) <- fdetail$selected.channels[[1]]
     
     tryCatch( gating <- kmeansFilter(value.x = parms), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     {
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }    
     }     
     callgate(gating, name)
 
   
 }  
  
}


norm2 <- function(mode)
{
  fdetail<- ask.dialog("Norm2Filter",channel.selections = c("X Channel", "Y Channel") )
  if(fdetail$ok)
  {
   
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    
    tryCatch(gating <- norm2Filter(parms), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                 })
    
    iset("value.x", fdetail$selected.channels[[1]])
    iset("value.y", fdetail$selected.channels[[2]])
   
    ## FIXME : it needs to make a filter list then addSubNode from the list by drag and drop.
    ## make it available to plot.
    
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))
     {  
       while(name %in% names(.guiEnv$Gate.list))
       {  
       name <- paste(name, "*")
       }
       
     }     
     callgate(gating, name)
    
  }  
  
}


curv1 <- function(mode)
{
 
  fdetail<- ask.dialog("Curv1Filter",channel.selections = c("Channel") )
  if(fdetail$ok)
  {
   
    parms <- fdetail$selected.channels[[1]]
     
     tryCatch( gating <- curv1Filter(x = parms ), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     {
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }    
     }     
     callgate(gating, name)
 
   
 }  
  
}



curv2 <- function(mode)
{
  fdetail<- ask.dialog("Curv2Filter",channel.selections = c("X Channel", "Y Channel") )
  if(fdetail$ok)
  {
   
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    
    tryCatch(gating <- curv2Filter(parms), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                 })
    
    iset("value.x", fdetail$selected.channels[[1]])
    iset("value.y", fdetail$selected.channels[[2]])
   
    ## FIXME : it needs to make a filter list then addSubNode from the list by drag and drop.
    ## make it available to plot.
    
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))
     {  
       while(name %in% names(.guiEnv$Gate.list))
       {  
       name <- paste(name, "*")
       }
       
     }     
     callgate(gating, name)
    
  }  
  
}

#############################################################################################
#### FOR GUI OUTLINE ########################################################################

ask.dialog <- function(title, channel.selections = c("X Channel", "Y Channel"))
{
   if (!isAnyActive()) 
    {
        show.message("No active dataset")
        return()
    }
    
    dialog <- gtkDialogNewWithButtons(title, iget("window"), "destroy-with-parent", 
                                          "gtk-ok", GtkResponseType["ok"], "gtk-cancel", GtkResponseType["cancel"])
       
    dialog$setResponseSensitive(GtkResponseType["ok"], FALSE)
    
    namebox <- gtkHBox(FALSE, 0)
    dialog[["vbox"]]$packStart(namebox, FALSE, FALSE, 5)
     
    label <- gtkLabelNew(" Gate name : ")
    from <- gtkEntryNew()
    from$setText(title)
    from$"has-focus" <- TRUE
    namebox$packStart(label, FALSE, FALSE, 0)
    namebox$packStart(from, TRUE, TRUE, 0)
    
    updateOKButton <- function(sel, udata = NULL)
    {
        make.sensitive <- TRUE
     #   for (cv in channel.views)
     #       if (length(getSelectedIndices(cv)) == 0)
     #           make.sensitive <- FALSE
        dialog$setResponseSensitive(GtkResponseType["ok"], make.sensitive)
    }
    
    channels <- colnames(activeFlowset())
    main.box <- gtkHBox(FALSE, 10)
    dialog[["vbox"]]$packStart(main.box, FALSE, FALSE, 0)
    
    channelSelectWidget <- function(i)
    {
        outchannel <- gtkFrame("")
        chbox <- gtkHBox(FALSE, 5)
        chbox$setSizeRequest(250, 350)
        outchannel$add(chbox)
        main.box$packStart(outchannel, TRUE, TRUE, 0)
        ## The list of available channels
        view <- make.treeview(channels,channel.selections[i], "single")
        sw2 <- make.scrolled_window(view)
        chbox$packStart(sw2, TRUE, TRUE, 0)
        gSignalConnect(view$getSelection(), "changed", updateOKButton, NULL)
        view
    }
    
     channel.views <- lapply(seq_along(channel.selections), channelSelectWidget)
     names(channel.views) <- channel.selections
     
         
     diag.run <- dialog$run()
     
     if (diag.run == GtkResponseType["ok"])
     {
       name <- from$getText()
       ans <- list(ok = TRUE, id = name)
      
       ans$selected.channels <- lapply(channel.views, function(v) channels[getSelectedIndices(v)])
        ans <-
            within(ans,
               {
                   for (i in selected.channels)
                       if (length(i) == 0) ok <- FALSE
               })
        if(title == "RectangleGate" || title == "QuadrantGate")
        {
                  win <- iget("window")
                  ans <- ask2.dialog(title, sub ="Enter boundaries", win, ans)
                  
        }         
      }
     else ## if (diag.run %in% GtkResponseType[c("cancel", "delete-event")])
    {
        ans <- list(ok = FALSE)
        loc <- list("", "")
        ans <- list(ans, loc)
       
    }
    dialog$destroy()
    ans
    
}  


ask2.dialog <- function(title, sub ="", win, ans)
{
   if (!isAnyActive()) 
    {
        show.message("No active dataset")
        return()
    }
    
    dialog <- gtkDialogNewWithButtons(sub, win, "destroy-with-parent", 
                                          "gtk-ok", GtkResponseType["ok"], "gtk-cancel", GtkResponseType["cancel"])
   
     ## draw graphics to help it find boundaries.
     df <- activeFlowset()
     x <- ans$selected.channels[[1]]
     y <- ans$selected.channels[[2]]
     
          
     swt <- "FALSE"
     
      dev.new()
       form <- sprintf("`%s` ~ `%s`", x, y) 
       fcall <- sprintf("xyplot(%s, data=df)", form)
       plot(eval(parse(text = fcall))) 
       
       
     ## Give the location for gating
     if(title == "QuadrantGate")
            loc <- gtkFrame("Line")
     else     
            loc <- gtkFrame("location")
          
     
     vbox <- gtkVBoxNew(FALSE, 0)
     loc$add(vbox)
     dialog[["vbox"]]$packStart(loc, FALSE, FALSE, 0)
     
     if(title == "QuadrantGate") {
       hbox.x <- gtkHBoxNew(FALSE, 0)
       horizon <- sprintf("%s :", x)
       vertical <- sprintf("%s :", y)
       label.from <- gtkLabelNew(horizon)
       label.to <- gtkLabelNew(vertical)
        wentry.from <- gtkEntryNew()
       wentry.to <- gtkEntryNew()
       hbox.x$packStart(label.from, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.from, FALSE, FALSE, 5)
       hbox.x$packStart(label.to, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.x, FALSE, FALSE, 0)
       
      
    }
     else{
       hbox.x <- gtkHBoxNew(FALSE, 0)
       horizon <- sprintf("%s :", x)
       label.x <- gtkLabelNew(horizon)
       label.from <- gtkLabelNew("from-")
       label.to <- gtkLabelNew("to-")
       wentry.from <- gtkEntryNew()
       wentry.to <- gtkEntryNew()
       hbox.x$packStart(label.x, FALSE, FALSE, 5)
       hbox.x$packStart(label.from, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.from, FALSE, FALSE, 5)
       hbox.x$packStart(label.to, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.x, FALSE, FALSE, 0)
          
       hbox.y <- gtkHBoxNew(FALSE, 0)
       vertical <- sprintf("%s :", y)
       label.y <- gtkLabelNew(vertical)
       hentry.from <- gtkEntryNew()
       hentry.to <- gtkEntryNew()
       label.from <- gtkLabelNew("from-")
       label.to <- gtkLabelNew("to-")
       hbox.y$packStart(label.y, FALSE, FALSE, 5)
       hbox.y$packStart(label.from, FALSE, FALSE, 7)
       hbox.y$packStart(hentry.from, FALSE, FALSE, 5)
       hbox.y$packStart(label.to, FALSE, FALSE, 10)
       hbox.y$packStart(hentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.y, FALSE, FALSE, 0)
     
     
     }      
     
     
 #    if(title == "RectangleGate"){
 ##         plot.new()
 #         form <- sprintf("`%s` ~ `%s`", x, y) 
 #         fcall <- sprintf("xyplot(%s, data=df)", form)
 #         plot(eval(parse(text = fcall))) 
 #    
 #         los <-location <- locator(n =512, type = "o")
 #         swt <- "TRUE"   
 #     }
     diag.run <- dialog$run()
     
     if (diag.run == GtkResponseType["ok"])
     {
       
       ## for rectangleGate and quadGate
      
       ## by drawing of regions for rectgate
       if(swt == "TRUE"){
       	       
  #     	      browser() 
              wx <- los$x[1]*1000
              wy <- los$x[2]*1000
              
              hx <- los$y[1]*1000
              hy <- los$y[2]*1000
              }
       else{
       
          wx <-as.numeric(wentry.from$getText())
          wy <- as.numeric(wentry.to$getText())  }
          
          
       if(title == "RectangleGate")
       {
       
         if(swt == "FALSE")  
         {    
           hx <- as.numeric(hentry.from$getText())
           hy <- as.numeric(hentry.to$getText())
          }
          
         loc <- list(c(wx, wy), c(hx, hy))
         ans <- c(ans, loc)
       }
       else
       {
         loc <- list(wx, wy)
         ans <- c(ans, loc)
       }
       dev.off()
     }  
    dialog$destroy()
    ans
    
}

==> iFlow_2.6.0.tar.gz: iFlow/R/openFilter.R <==
write.list <- function()
{
  ## update filter list on the data panel
   n <- length(names(.guiEnv$Gate.list))
   iget("fcon")$appendRows(data.frame(cols = names(.guiEnv$Gate.list)[n]))
}  


callgate <- function(gating, id)
{
  .guiEnv$Gate.list[[id]] <- gating

   write.list()
  
} 
                                                     


rect <- function (mode) 
{
    
    fdetail <- ask.dialog("RectangleGate",channel.selections = c("X Channel", "Y Channel") )
     
     parms<-list(fdetail[[6]], fdetail[[5]])
     names(parms) <- c(fdetail$selected.channels[[2]], fdetail$selected.channels[[1]])
     
      name <- fdetail$id[1]
      if(name %in% names(.guiEnv$Gate.list)) 
     { 
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }
     }  
        
     tryCatch( gating <- rectangleGate(parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
    
     callgate(gating, name)
     
 }  


range <- function(mode)
{
  fdetail<- ask.dialog("RangeGate",channel.selections = c("Channel") )
  if(fdetail$ok)
  {
   	parms <- fdetail$selected.channels[[1]]	 
   	name <- fdetail$id[1]
   	
       if(name %in% names(.guiEnv$Gate.list))  
       {
            while(name %in% names(.guiEnv$Gate.list))
            {  
                   name <- paste(name, collapse = "*")
            }    
       }     
       
       
   	tryCatch( gating <- rangeFilter(parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
       iset("value.x", fdetail$selected.channels[[1]])
     
    
       callgate(gating, name)
  }	  
	
}

 
 
quad <- function(mode)
{
   fdetail<- ask.dialog("QuadrantGate",channel.selections = c("X Channel", "Y Channel") )
   
   parms <- list(fdetail[[5]], fdetail[[6]])
   names(parms) <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
   
    name <- fdetail$id[1]
    if(name %in% names(.guiEnv$Gate.list))
     {
       while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
        }
     }  
    
   tryCatch( gating <- quadGate(parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })

     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
     
     callgate(gating, name)
    
 }


 
 
 lymph <- function(mode)
{
   
  fdetail<- ask.dialog("LymphFilter",channel.selections = c("X Channel", "Y Channel", "PreSelection") )
  if(fdetail$ok)
  {
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    pre <- fdetail$selected.channels[[3]]
    
    name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     { 
        while(name %in% names(.guiEnv$Gate.list))
       {   
            name <- paste(name, collapse = "*")
       }
     }
     
    tryCatch( gating <- lymphFilter(parms, preselection = pre, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
    
     iset("value.x", fdetail$selected.channels[[1]])
     iset("value.y", fdetail$selected.channels[[2]])
      
     callgate(gating, name)
   
 }  
  
}



 
k_mean <- function(mode)
{
 
  fdetail<- ask.dialog("Kmeans",channel.selections = c("Channel") )
  if(fdetail$ok)
  {
   
     parms <- list(c("Low", "Medium", "High"))
     
     names(parms) <- fdetail$selected.channels[[1]]
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     {
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }    
     }     
     
     tryCatch( gating <- kmeansFilter(value.x = parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     
    
     callgate(gating, name)
 
   
 }  
  
}


norm2 <- function(mode)
{
  fdetail<- ask.dialog("Norm2Filter",channel.selections = c("X Channel", "Y Channel") )
  if(fdetail$ok)
  {
   
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))
     {  
       while(name %in% names(.guiEnv$Gate.list))
       {  
       name <- paste(name, "*")
       }
       
     }     
    
    tryCatch(gating <- norm2Filter(parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                 })
    
    iset("value.x", fdetail$selected.channels[[1]])
    iset("value.y", fdetail$selected.channels[[2]])
   
    ## FIXME : it needs to make a filter list then addSubNode from the list by drag and drop.
    ## make it available to plot.
    
    callgate(gating, name)
    
  }  
  
}


curv1 <- function(mode)
{
 
  fdetail<- ask.dialog("Curv1Filter",channel.selections = c("Channel") )
  if(fdetail$ok)
  {
   
    parms <- fdetail$selected.channels[[1]]
    
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))  
     {
        while(name %in% names(.guiEnv$Gate.list))
       {  
            name <- paste(name, collapse = "*")
       }    
     }     
     
     tryCatch( gating <- curv1Filter(x = parms, filterId = name ), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                })
     
     iset("value.x", fdetail$selected.channels[[1]])
     
     callgate(gating, name)
 
   
 }  
  
}



curv2 <- function(mode)
{
  fdetail<- ask.dialog("Curv2Filter",channel.selections = c("X Channel", "Y Channel") )
  if(fdetail$ok)
  {
   
    parms <- c(fdetail$selected.channels[[1]], fdetail$selected.channels[[2]])
    
     name <- fdetail$id[1]
     if(name %in% names(.guiEnv$Gate.list))
     {  
       while(name %in% names(.guiEnv$Gate.list))
       {  
       name <- paste(name, "*")
       }
       
     }     
    
    tryCatch(gating <- curv2Filter(parms, filterId = name), 
                 ## if error happens, show up another dialog to notify error message and destroy dialog for open menu
                 error = function(e) {
                     m <- paste("Error: ", conditionMessage(e))
                     error.handler(m)
                 }, 
                 warning = function(e) {
                     m <- paste("Warning: ", conditionMessage(e))
                     warning.handler(m)
                     
                 })
    
    iset("value.x", fdetail$selected.channels[[1]])
    iset("value.y", fdetail$selected.channels[[2]])
   
    ## FIXME : it needs to make a filter list then addSubNode from the list by drag and drop.
    ## make it available to plot.
    
    
     callgate(gating, name)
    
  }  
  
}

#############################################################################################
#### FOR GUI OUTLINE ########################################################################

ask.dialog <- function(title, channel.selections = c("X Channel", "Y Channel"))
{
   if (!isAnyActive()) 
    {
        show.message("No active dataset")
        return()
    }
    
    dialog <- gtkDialogNewWithButtons(title, iget("window"), "destroy-with-parent", 
                                          "gtk-ok", GtkResponseType["ok"], "gtk-cancel", GtkResponseType["cancel"])
       
    dialog$setResponseSensitive(GtkResponseType["ok"], FALSE)
    
    namebox <- gtkHBox(FALSE, 0)
    dialog[["vbox"]]$packStart(namebox, FALSE, FALSE, 5)
     
    label <- gtkLabelNew(" Gate name : ")
    from <- gtkEntryNew()
    from$setText(title)
    from$"has-focus" <- TRUE
    namebox$packStart(label, FALSE, FALSE, 0)
    namebox$packStart(from, TRUE, TRUE, 0)
    
    updateOKButton <- function(sel, udata = NULL)
    {
        make.sensitive <- TRUE
     #   for (cv in channel.views)
     #       if (length(getSelectedIndices(cv)) == 0)
     #           make.sensitive <- FALSE
        dialog$setResponseSensitive(GtkResponseType["ok"], make.sensitive)
    }
    
    channels <- colnames(activeFlowset())
    main.box <- gtkHBox(FALSE, 10)
    dialog[["vbox"]]$packStart(main.box, FALSE, FALSE, 0)
    
    channelSelectWidget <- function(i)
    {
        outchannel <- gtkFrame("")
        chbox <- gtkHBox(FALSE, 5)
        chbox$setSizeRequest(250, 350)
        outchannel$add(chbox)
        main.box$packStart(outchannel, TRUE, TRUE, 0)
        ## The list of available channels
        view <- make.treeview(channels,channel.selections[i], "single")
        sw2 <- make.scrolled_window(view)
        chbox$packStart(sw2, TRUE, TRUE, 0)
        gSignalConnect(view$getSelection(), "changed", updateOKButton, NULL)
        view
    }
    
     channel.views <- lapply(seq_along(channel.selections), channelSelectWidget)
     names(channel.views) <- channel.selections
     
         
     diag.run <- dialog$run()
     
     if (diag.run == GtkResponseType["ok"])
     {
       name <- from$getText()
       ans <- list(ok = TRUE, id = name)
      
       ans$selected.channels <- lapply(channel.views, function(v) channels[getSelectedIndices(v)])
        ans <-
            within(ans,
               {
                   for (i in selected.channels)
                       if (length(i) == 0) ok <- FALSE
               })
        if(title == "RectangleGate" || title == "QuadrantGate")
        {
                  win <- iget("window")
                  ans <- ask2.dialog(title, sub ="Enter boundaries", win, ans)
                  
        }         
      }
     else ## if (diag.run %in% GtkResponseType[c("cancel", "delete-event")])
    {
        ans <- list(ok = FALSE)
        loc <- list("", "")
        ans <- list(ans, loc)
       
    }
    dialog$destroy()
    ans
    
}  


ask2.dialog <- function(title, sub ="", win, ans)
{
   if (!isAnyActive()) 
    {
        show.message("No active dataset")
        return()
    }
    
    dialog <- gtkDialogNewWithButtons(sub, win, "destroy-with-parent", 
                                          "gtk-ok", GtkResponseType["ok"], "gtk-cancel", GtkResponseType["cancel"])
   
     ## draw graphics to help it find boundaries.
     df <- activeFlowset()
     x <- ans$selected.channels[[1]]
     y <- ans$selected.channels[[2]]
     
          
     swt <- "FALSE"
     
      dev.new()
       form <- sprintf("`%s` ~ `%s`", x, y) 
       fcall <- sprintf("xyplot(%s, data=df)", form)
       plot(eval(parse(text = fcall))) 
       
       
     ## Give the location for gating
     if(title == "QuadrantGate")
            loc <- gtkFrame("Line")
     else     
            loc <- gtkFrame("location")
          
     
     vbox <- gtkVBoxNew(FALSE, 0)
     loc$add(vbox)
     dialog[["vbox"]]$packStart(loc, FALSE, FALSE, 0)
     
     if(title == "QuadrantGate") {
       hbox.x <- gtkHBoxNew(FALSE, 0)
       horizon <- sprintf("%s :", x)
       vertical <- sprintf("%s :", y)
       label.from <- gtkLabelNew(horizon)
       label.to <- gtkLabelNew(vertical)
        wentry.from <- gtkEntryNew()
       wentry.to <- gtkEntryNew()
       hbox.x$packStart(label.from, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.from, FALSE, FALSE, 5)
       hbox.x$packStart(label.to, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.x, FALSE, FALSE, 0)
       
      
    }
     else{
       hbox.x <- gtkHBoxNew(FALSE, 0)
       horizon <- sprintf("%s :", x)
       label.x <- gtkLabelNew(horizon)
       label.from <- gtkLabelNew("from-")
       label.to <- gtkLabelNew("to-")
       wentry.from <- gtkEntryNew()
       wentry.to <- gtkEntryNew()
       hbox.x$packStart(label.x, FALSE, FALSE, 5)
       hbox.x$packStart(label.from, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.from, FALSE, FALSE, 5)
       hbox.x$packStart(label.to, FALSE, FALSE, 10)
       hbox.x$packStart(wentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.x, FALSE, FALSE, 0)
          
       hbox.y <- gtkHBoxNew(FALSE, 0)
       vertical <- sprintf("%s :", y)
       label.y <- gtkLabelNew(vertical)
       hentry.from <- gtkEntryNew()
       hentry.to <- gtkEntryNew()
       label.from <- gtkLabelNew("from-")
       label.to <- gtkLabelNew("to-")
       hbox.y$packStart(label.y, FALSE, FALSE, 5)
       hbox.y$packStart(label.from, FALSE, FALSE, 7)
       hbox.y$packStart(hentry.from, FALSE, FALSE, 5)
       hbox.y$packStart(label.to, FALSE, FALSE, 10)
       hbox.y$packStart(hentry.to, FALSE, FALSE, 10)
       vbox$packStart(hbox.y, FALSE, FALSE, 0)
     
     
     }      
     
     
 #    if(title == "RectangleGate"){
 ##         plot.new()
 #         form <- sprintf("`%s` ~ `%s`", x, y) 
 #         fcall <- sprintf("xyplot(%s, data=df)", form)
 #         plot(eval(parse(text = fcall))) 
 #    
 #         los <-location <- locator(n =512, type = "o")
 #         swt <- "TRUE"   
 #     }
     diag.run <- dialog$run()
     
     if (diag.run == GtkResponseType["ok"])
     {
       
       ## for rectangleGate and quadGate
      
       ## by drawing of regions for rectgate
       if(swt == "TRUE"){
       	       
  #     	      browser() 
              wx <- los$x[1]*1000
              wy <- los$x[2]*1000
              
              hx <- los$y[1]*1000
              hy <- los$y[2]*1000
              }
       else{
       
          wx <-as.numeric(wentry.from$getText())
          wy <- as.numeric(wentry.to$getText())  }
          
          
       if(title == "RectangleGate")
       {
       
         if(swt == "FALSE")  
         {    
           hx <- as.numeric(hentry.from$getText())
           hy <- as.numeric(hentry.to$getText())
          }
          
         loc <- list(c(wx, wy), c(hx, hy))
         ans <- c(ans, loc)
       }
       else
       {
         loc <- list(wx, wy)
         ans <- c(ans, loc)
       }
       dev.off()
     }  
    dialog$destroy()
    ans
    
}
